..
   Copyright (C) 2014 Jaakko Luttinen

   This file is licensed under the MIT License. See LICENSE for a text of the
   license.


Examples
********

.. toctree::
   :maxdepth: 1

   multinomial
   regression
   gmm
   bmm
   hmm
   pca
   lssm
   lda
